# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/contest.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc7\x03\n\x07\x43ontest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.eolymp.judge.Contest.Type\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\tstarts_in\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x07\x65nds_in\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08\x64uration\x18\x0c \x01(\x05\x12,\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.Status\x12\x0e\n\x06public\x18\x1e \x01(\x08\x12\x0e\n\x06\x64omain\x18( \x01(\t\">\n\x06Status\x12\r\n\tNO_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\"\"\n\x04Type\x12\x0b\n\x07NO_TYPE\x10\x00\x12\r\n\tCHALLENGE\x10\x01\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_CONTEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Contest.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_STATUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=467,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_CONTEST_STATUS)

_CONTEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Contest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHALLENGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=531,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_CONTEST_TYPE)


_CONTEST = _descriptor.Descriptor(
  name='Contest',
  full_name='eolymp.judge.Contest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Contest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.Contest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Contest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_at', full_name='eolymp.judge.Contest.starts_at', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_in', full_name='eolymp.judge.Contest.starts_in', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_at', full_name='eolymp.judge.Contest.ends_at', index=5,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_in', full_name='eolymp.judge.Contest.ends_in', index=6,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='eolymp.judge.Contest.duration', index=7,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Contest.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='eolymp.judge.Contest.public', index=9,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='eolymp.judge.Contest.domain', index=10,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTEST_STATUS,
    _CONTEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=565,
)

_CONTEST.fields_by_name['type'].enum_type = _CONTEST_TYPE
_CONTEST.fields_by_name['starts_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTEST.fields_by_name['starts_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONTEST.fields_by_name['ends_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTEST.fields_by_name['ends_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONTEST.fields_by_name['status'].enum_type = _CONTEST_STATUS
_CONTEST_STATUS.containing_type = _CONTEST
_CONTEST_TYPE.containing_type = _CONTEST
DESCRIPTOR.message_types_by_name['Contest'] = _CONTEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Contest = _reflection.GeneratedProtocolMessageType('Contest', (_message.Message,), {
  'DESCRIPTOR' : _CONTEST,
  '__module__' : 'eolymp.judge.contest_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Contest)
  })
_sym_db.RegisterMessage(Contest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/template.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/atlas/template.proto',
  package='eolymp.atlas',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/atlas;atlas',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x65olymp/atlas/template.proto\x12\x0c\x65olymp.atlas\"k\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0e\n\x06header\x18\x0b \x01(\t\x12\x0e\n\x06\x66ooter\x18\x0c \x01(\tB3Z1github.com/eolymp/contracts/go/eolymp/atlas;atlasb\x06proto3'
)




_TEMPLATE = _descriptor.Descriptor(
  name='Template',
  full_name='eolymp.atlas.Template',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.atlas.Template.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.atlas.Template.problem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='eolymp.atlas.Template.runtime', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.atlas.Template.source', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='eolymp.atlas.Template.header', index=4,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer', full_name='eolymp.atlas.Template.footer', index=5,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=152,
)

DESCRIPTOR.message_types_by_name['Template'] = _TEMPLATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Template = _reflection.GeneratedProtocolMessageType('Template', (_message.Message,), {
  'DESCRIPTOR' : _TEMPLATE,
  '__module__' : 'eolymp.atlas.template_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.atlas.Template)
  })
_sym_db.RegisterMessage(Template)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/language.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/language.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/executor/language.proto\x12\x0f\x65olymp.executor\"8\n\x08Language\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x12\n\ndeprecated\x18\x0b \x01(\x08\x42\x39Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
)




_LANGUAGE = _descriptor.Descriptor(
  name='Language',
  full_name='eolymp.executor.Language',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.executor.Language.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.executor.Language.name', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='eolymp.executor.Language.deprecated', index=2,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=107,
)

DESCRIPTOR.message_types_by_name['Language'] = _LANGUAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Language = _reflection.GeneratedProtocolMessageType('Language', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGE,
  '__module__' : 'eolymp.executor.language_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.Language)
  })
_sym_db.RegisterMessage(Language)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/ticket.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/ticket.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65olymp/judge/ticket.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\"\x85\x02\n\x06Ticket\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12\x16\n\x0eparticipant_id\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\n \x01(\t\x12\x0f\n\x07message\x18\x0b \x01(\t\x12\x0f\n\x07is_open\x18\x14 \x01(\x08\x12\x1e\n\x16is_read_by_participant\x18\x15 \x01(\x08\x12\x18\n\x10is_read_by_owner\x18\x16 \x01(\x08\x12.\n\ncreated_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x07is_read\x18\x87N \x01(\x08\x12\x14\n\x0bneeds_reply\x18\x88N \x01(\x08\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TICKET = _descriptor.Descriptor(
  name='Ticket',
  full_name='eolymp.judge.Ticket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Ticket.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Ticket.contest_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='eolymp.judge.Ticket.participant_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='eolymp.judge.Ticket.subject', index=3,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='eolymp.judge.Ticket.message', index=4,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_open', full_name='eolymp.judge.Ticket.is_open', index=5,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read_by_participant', full_name='eolymp.judge.Ticket.is_read_by_participant', index=6,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read_by_owner', full_name='eolymp.judge.Ticket.is_read_by_owner', index=7,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='eolymp.judge.Ticket.created_at', index=8,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read', full_name='eolymp.judge.Ticket.is_read', index=9,
      number=9991, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='needs_reply', full_name='eolymp.judge.Ticket.needs_reply', index=10,
      number=9992, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=338,
)

_TICKET.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Ticket'] = _TICKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ticket = _reflection.GeneratedProtocolMessageType('Ticket', (_message.Message,), {
  'DESCRIPTOR' : _TICKET,
  '__module__' : 'eolymp.judge.ticket_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Ticket)
  })
_sym_db.RegisterMessage(Ticket)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/apollo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.apollo import submission_pb2 as eolymp_dot_apollo_dot_submission__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/apollo.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/apollo.proto\x12\reolymp.apollo\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/apollo/submission.proto\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"I\n\x18\x44\x65scribeSubmissionOutput\x12-\n\nsubmission\x18\x01 \x01(\x0b\x32\x19.eolymp.apollo.Submission2\xfe\x02\n\x06\x41pollo\x12\xb4\x01\n\x10\x43reateSubmission\x12$.eolymp.apollo.CreateSubmissionInput\x1a%.eolymp.apollo.CreateSubmissionOutput\"S\x82\xe3\n\x1b\x8a\xe3\n\x17\x61pollo:submission:write\x82\xd3\xe4\x93\x02.\")/apollo/problems/{problem_id}/submissions:\x01*\x12\xbc\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.apollo.DescribeSubmissionInput\x1a\'.eolymp.apollo.DescribeSubmissionOutput\"U\x82\xe3\n\x1a\x8a\xe3\n\x16\x61pollo:submission:read\x82\xd3\xe4\x93\x02\x31\x12#/apollo/submissions/{submission_id}b\nsubmissionB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_apollo_dot_submission__pb2.DESCRIPTOR,])




_CREATESUBMISSIONINPUT = _descriptor.Descriptor(
  name='CreateSubmissionInput',
  full_name='eolymp.apollo.CreateSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.CreateSubmissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.apollo.CreateSubmissionInput.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.apollo.CreateSubmissionInput.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=213,
)


_CREATESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='CreateSubmissionOutput',
  full_name='eolymp.apollo.CreateSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.apollo.CreateSubmissionOutput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=262,
)


_DESCRIBESUBMISSIONINPUT = _descriptor.Descriptor(
  name='DescribeSubmissionInput',
  full_name='eolymp.apollo.DescribeSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.apollo.DescribeSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=312,
)


_DESCRIBESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='DescribeSubmissionOutput',
  full_name='eolymp.apollo.DescribeSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.apollo.DescribeSubmissionOutput.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=387,
)

_DESCRIBESUBMISSIONOUTPUT.fields_by_name['submission'].message_type = eolymp_dot_apollo_dot_submission__pb2._SUBMISSION
DESCRIPTOR.message_types_by_name['CreateSubmissionInput'] = _CREATESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionOutput'] = _CREATESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionInput'] = _DESCRIBESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionOutput'] = _DESCRIBESUBMISSIONOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSubmissionInput = _reflection.GeneratedProtocolMessageType('CreateSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONINPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.CreateSubmissionInput)
  })
_sym_db.RegisterMessage(CreateSubmissionInput)

CreateSubmissionOutput = _reflection.GeneratedProtocolMessageType('CreateSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.CreateSubmissionOutput)
  })
_sym_db.RegisterMessage(CreateSubmissionOutput)

DescribeSubmissionInput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONINPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.DescribeSubmissionInput)
  })
_sym_db.RegisterMessage(DescribeSubmissionInput)

DescribeSubmissionOutput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.DescribeSubmissionOutput)
  })
_sym_db.RegisterMessage(DescribeSubmissionOutput)


DESCRIPTOR._options = None

_APOLLO = _descriptor.ServiceDescriptor(
  name='Apollo',
  full_name='eolymp.apollo.Apollo',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=390,
  serialized_end=772,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSubmission',
    full_name='eolymp.apollo.Apollo.CreateSubmission',
    index=0,
    containing_service=None,
    input_type=_CREATESUBMISSIONINPUT,
    output_type=_CREATESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027apollo:submission:write\202\323\344\223\002.\")/apollo/problems/{problem_id}/submissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSubmission',
    full_name='eolymp.apollo.Apollo.DescribeSubmission',
    index=1,
    containing_service=None,
    input_type=_DESCRIBESUBMISSIONINPUT,
    output_type=_DESCRIBESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026apollo:submission:read\202\323\344\223\0021\022#/apollo/submissions/{submission_id}b\nsubmission',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APOLLO)

DESCRIPTOR.services_by_name['Apollo'] = _APOLLO

# @@protoc_insertion_point(module_scope)
